@@ -33,6 +33,7 @@ import hubzero.config.webconfig
 import hubzero.data.db
 import ldap
 import ldap.modlist
+import os
 
 
 def _userExists(db, username):
@@ -46,13 +47,14 @@ def _userExists(db, username):
 	else:
 		return True
 
+
 def _del_jos_users(db, username):
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
 	userID = db.execSelectQueryScalar(sql, data)	
 
 	sql = 'delete from `jos_users` where userid = %s'
-	data = (userid)
+	data = (userID)
 	userID = db.execSelectQueryScalar(sql, data)	
 
 	return userID
@@ -60,17 +62,19 @@ def _del_jos_users(db, username):
 
 def _del_jos_core_acl_aro(db, userID):
 
-	sql = 'select id from `jos_core_acl_aro` where value = %s'
+	sql = 'select id from `jos_core_acl_aro` where `value` = %s'
 	data = (userID)
 	aroID = db.execSelectQueryScalar(sql, data)	
 
-	sql = "DELETE FROM `jos_core_acl_aro` where `value` = %s  "
+	sql = "DELETE FROM `jos_core_acl_aro` where `value` = %s"
 	data = (userID)
 	db.execQuery(sql, data)
 	
 	return aroID
 
+
 def _del_jos_core_acl_groups_aro_map(db, aroID):
+	print "aroID = " + str(aroID)
 	sql = "DELETE FROM `jos_core_acl_groups_aro_map` WHERE `aro_id` = %s"
 	data = (aroID)
 	db.execQuery(sql, data)
@@ -138,7 +142,7 @@ def _insert_jos_users_password(db, userid, pw):
 	db.execQuery(sql, data)
 
 
-def _add_ldap_user(username, password, uidNumber, homeDir):
+def _add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell):
 
 	# get ldapManagerUserDN and PW
 	
@@ -162,6 +166,8 @@ def _add_ldap_user(username, password, uidNumber, homeDir):
 	attrs['uid'] = username
 	attrs['uidNumber'] = str(uidNumber)
 	attrs['homeDirectory'] = homeDir
+	attrs['cn'] = gecos
+	attrs['loginShell'] = loginShell
 	
 	# TODO: grab this from the com_members component parm field
 	attrs['gidNumber'] = "100"
@@ -185,7 +191,7 @@ def _delete_ldap_user(username):
 	l.delete_s(dn)
 
 
-def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, joomlagid, 
+def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid, 
                joomlagidNumber, gid, gidNumber, joomlauserid, loginShell, nocreatehome, homeDir, createGroup, 
                skipldap):
 
@@ -199,8 +205,28 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 	if _userExists(db, username):
 		print "User already exists: " + username
 		return (-1)
+
+
+	# parse gecos, it's a massive mess, but it's a comma delimited field used in the /etc/passwd file to store personal info
+	# it's comma delimited, and name is the first item in the list... right now we don't care about what else gets passed,
+	# but the first entry
+	gecosFields = gecos.split(",")
+	fullName = gecosFields[0]
+	fullNameList = gecosFields[0].split(" ")
+	
+	if len(fullName) == 3:
+		firstName = fullName[0]
+		middleName = fullName[1]
+		lastName = fullName[2]
+	elif len(fullName) == 2:
+		firstName = fullName[0]
+		middleName = ""
+		lastName = fullName[1]
+	else:
+		firstName = fullName[0]
+		middleName = ""
+		lastName = ""
 	
-	fullname = fname + ' ' + lname
 
 	# usually homeDir will be blank, but not always
 	if homeDir == "":
@@ -210,10 +236,10 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 	if pwdisabled: 
 		pw = "*"
 
-	userID = _insert_jos_users(db, joomlauserid, fullname, username, email, pw, joomlagid, joomlagidNumber)
-	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
+	userID = _insert_jos_users(db, joomlauserid, fullName, username, email, pw, joomlagid, joomlagidNumber)
+	aroID = _insert_jos_core_acl_aro(db, userID, fullName)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
-	_insert_jos_xprofiles(db, hubname, userID, fname, mname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
+	_insert_jos_xprofiles(db, hubname, userID, firstName, middleName, lastName, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir)
 	_insert_jos_users_password(db, userID, pw)
 
 
@@ -224,7 +250,13 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		hubzero.utilities.group._insert_jos_xgroups_members(db, gidNumber, userID)
 
 		hubzero.utilities.group._add_ldap_group(username, username + " group", gidNumber)
+	else:
+		gidNumber = 100 # default to the users group
 		
+	
+	if not skipldap:
+		_add_ldap_user(username, gecos, pw, userID, homeDir, loginShell)
+
 
 	# create home directory
 	if not nocreatehome:
@@ -233,28 +265,35 @@ def addhubuser(hubname, username, fname, mname, lname, email, pw, pwdisabled, jo
 		if rc:
 			print procStdErr
 		
-		# set ownerships
-		rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
-		print procStdOut
-		if rc:
-			print procStdErr
-
-	
-	if not skipldap:
-		_add_ldap_user(username, pw, userID, homeDir)
+		print "creating homedir: " + homeDir
+		
+		# set ownership
+		os.chown(homeDir, userID, gidNumber)
+		
+		#rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chown", username + "." + username, homeDir])
+		#print procStdOut
+		#if rc:
+		#	print procStdErr
 		
 	return(0)
 
 	
 def delhubuser(username):
 	# grab config options
-	dbPW = hubzero.config.passwords.getMySqlPW()
-	db =  hubzero.data.db.mySql("localhost", "myhub", "myhub", dbPW)
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
 	
 	sql = 'select id from `jos_users` where username = %s'
 	data = (username)
 	userID = db.execSelectQueryScalar(sql, data)
+
+	print "deleting user (" + username + ") from database"
+	
 	aroID = _del_jos_core_acl_aro(db, userID)
 	_del_jos_core_acl_groups_aro_map(db, aroID)
-	_del_jos_xprofiles(db, userID)	
+	_del_jos_xprofiles(db, userID)
+	_del_jos_users(db, username)
+	
 	_delete_ldap_user(username)
